@@ -1,6 +1,11 @@
+from ocp_resources.constants import TIMEOUT_4MINUTES
+from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 
 
+LOGGER = get_logger(name=__name__)
+
+
 class CatalogSource(NamespacedResource):
     api_group = NamespacedResource.ApiGroup.OPERATORS_COREOS_COM
 
@@ -15,6 +20,8 @@ class CatalogSource(NamespacedResource):
         publisher=None,
         teardown=True,
         yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
+        **kwargs,
     ):
         super().__init__(
             name=name,
@@ -22,6 +29,8 @@ class CatalogSource(NamespacedResource):
             client=client,
             teardown=teardown,
             yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
+            **kwargs,
         )
         self.source_type = source_type
         self.image = image
