@@ -1,6 +1,10 @@
+from ocp_resources.logger import get_logger
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
+LOGGER = get_logger(name=__name__)
+
+
 def _get_status_condition_log_message(**status_condition):
     log_msg = "Waiting For: \n"
     for status_condition_name, status_condition in status_condition.items():
@@ -22,6 +26,7 @@ class MTV:
         StorageMap
         NetworkMap
         Host
+        ForkliftController
     """
 
     def __init__(self):
@@ -49,6 +54,7 @@ class MTV:
         STORAGE_MAP_READY = "The storage map is ready."
         PLAN_READY = "The migration plan is ready."
         PLAN_SUCCEEDED = "The plan execution has SUCCEEDED."
+        PLAN_FAILED = "The plan execution has FAILED."
         MIGRATION_READY = "The migration is ready."
         MIGRATION_RUNNING = "The migration is RUNNING"
         MIGRATION_SUCCEEDED = "The migration has SUCCEEDED."
@@ -72,7 +78,7 @@ class MTV:
         Wait for MTV Resource Status Conditions.
         """
 
-        self.logger.info(
+        LOGGER.info(
             _get_status_condition_log_message(
                 condition_status=condition_status,
                 condition_type=condition_type,
@@ -120,23 +126,25 @@ class MTV:
                         return
 
         except TimeoutExpiredError:
-            self.logger.error(
+            LOGGER.error(
                 msg=f"Last Status Condition of {self.kind} {self.name} was: {last_condition}"
             )
             raise
 
-    def wait_for_condition_ready(self):
+    def wait_for_condition_ready(self, wait_timeout=360):
         self.wait_for_resource_status(
             condition_message=self.condition_message_ready,
             condition_status=self.Condition.Status.TRUE,
             condition_type=self.Condition.READY,
+            wait_timeout=wait_timeout,
         )
 
-    def wait_for_condition_succeeded(self):
+    def wait_for_condition_succeeded(self, wait_timeout=600):
         self.wait_for_resource_status(
             condition_type=self.Status.SUCCEEDED,
             condition_message=self.condition_message_succeeded,
             condition_status=self.Condition.Status.TRUE,
+            wait_timeout=wait_timeout,
         )
 
     @property
